pytilities.geometry.discreterectangle — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.discreterectangle

class `pytilities.geometry.discreterectangle.` `DiscreteRectangle`(*args, **kwargs)

  A rectangle with discrete coordinates.

  This rectangle greatly resembles Rectangle, but works with a discrete coordinate space. All results are floored.

  `__delattr__`(*args, **kwargs)
  `__getattribute__`(*args, **kwargs)
  `__init__`(*args, **kwargs)
  `__setattr__`(*args, **kwargs)
  `_center_x`
  `_center_y`
  `height`

    Read-write, height of the rectangle

  `width`

    Read-write, width of the rectangle

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »